@@ -60,6 +60,17 @@ class BaseIdentifier(object):
         #   Python 3.x only.
         return self._value
 
+    def __eq__(self, other):
+        """
+        :return: ``True`` if this BaseIdentifier object is numerically the
+            same as other, ``False`` otherwise.
+        """
+        try:
+            return (self.__class__, self._value) == (other.__class__, other._value)
+        except AttributeError:
+            return NotImplemented
+
+
 #-----------------------------------------------------------------------------
 class OUI(BaseIdentifier):
     """
@@ -109,6 +120,14 @@ class OUI(BaseIdentifier):
         else:
             raise NotRegisteredError('OUI %r not registered!' % oui)
 
+    def __getstate__(self):
+        """:returns: Pickled state of an `OUI` object."""
+        return self._value, self.records
+
+    def __setstate__(self, state):
+        """:param state: data used to unpickle a pickled `OUI` object."""
+        self._value, self.records = state
+
     def _parse_data(self, data, offset, size):
         """Returns a dict record from raw OUI record data"""
         record = {
@@ -254,6 +273,14 @@ class IAB(BaseIdentifier):
         else:
             raise NotRegisteredError('IAB %r not unregistered!' % iab)
 
+    def __getstate__(self):
+        """:returns: Pickled state of an `IAB` object."""
+        return self._value, self.record
+
+    def __setstate__(self, state):
+        """:param state: data used to unpickle a pickled `IAB` object."""
+        self._value, self.record = state
+
     def _parse_data(self, data, offset, size):
         """Returns a dict record from raw IAB record data"""
         for line in data.split("\n"):
@@ -351,6 +378,29 @@ class EUI(BaseIdentifier):
         #   Choose a dialect for MAC formatting.
         self.dialect = dialect
 
+    def __getstate__(self):
+        """:returns: Pickled state of an `EUI` object."""
+        return self._value, self._module.version, self.dialect
+
+    def __setstate__(self, state):
+        """
+        :param state: data used to unpickle a pickled `EUI` object.
+
+        """
+        value, version, dialect = state
+
+        self._value = value
+
+        if version == 48:
+            self._module = _eui48
+        elif version == 64:
+            self._module = _eui64
+        else:
+            raise ValueError('unpickling failed for object state: %s' \
+                % str(state))
+
+        self.dialect = dialect
+
     def _get_value(self):
         return self._value
 
@@ -600,7 +650,7 @@ class EUI(BaseIdentifier):
         :return: new link local IPv6 `IPAddress` object based on this `EUI` \
             using the technique described in RFC 4291.
         """
-        int_val = 0xfe800000000000000200000000000000
+        int_val = 0xfe800000000000000000000000000000
 
         if self.version == 48:
             eui64_tokens = ["%02x" % i for i in self[0:3]] + ['ff', 'fe'] + \
@@ -608,6 +658,14 @@ class EUI(BaseIdentifier):
             int_val += int(''.join(eui64_tokens), 16)
         else:
             int_val += self._value
+        
+        # Modified EUI-64 format interface identifiers are formed by inverting
+        # the "u" bit (universal/local bit in IEEE EUI-64 terminology) when
+        # forming the interface identifier from IEEE EUI-64 identifiers.  In
+        # the resulting Modified EUI-64 format, the "u" bit is set to one (1)
+        # to indicate universal scope, and it is set to zero (0) to indicate
+        # local scope.
+        int_val ^= 0x00000000000000000200000000000000
 
         return IPAddress(int_val, 6)
 
