@@ -37,7 +37,7 @@ import sys as _sys
 import os.path as _path
 import csv as _csv
 
-from netaddr.core import Subscriber, Publisher, dos2unix
+from netaddr.core import Subscriber, Publisher
 
 #-----------------------------------------------------------------------------
 
@@ -263,50 +263,28 @@ def create_indices():
 #-----------------------------------------------------------------------------
 def load_indices():
     """Load OUI and IAB lookup indices into memory"""
-    for row in _csv.reader(open(OUI_METADATA)):
-        (key, offset, size) = [int(_) for _ in row]
-        OUI_INDEX.setdefault(key, [])
-        OUI_INDEX[key].append((offset, size))
+    fp = open(OUI_METADATA)
+    try:
+        for row in _csv.reader(fp):
+            (key, offset, size) = [int(_) for _ in row]
+            OUI_INDEX.setdefault(key, [])
+            OUI_INDEX[key].append((offset, size))
+    finally:
+        fp.close()
 
-    for row in _csv.reader(open(IAB_METADATA)):
-        (key, offset, size) = [int(_) for _ in row]
-        IAB_INDEX.setdefault(key, [])
-        IAB_INDEX[key].append((offset, size))
-
-#-----------------------------------------------------------------------------
-def get_latest_files():
-    """Download the latest files from the IEEE"""
-    if _sys.version_info[0] == 3:
-        #   Python 3.x
-        from urllib.request import Request, urlopen
-    else:
-        #   Python 2.x
-        from urllib2 import Request, urlopen
-
-    urls = [
-        'http://standards.ieee.org/regauth/oui/oui.txt',
-        'http://standards.ieee.org/regauth/oui/iab.txt',
-    ]
-
-    for url in urls:
-        _sys.stdout.write('downloading latest copy of %s\n' % url)
-        request = Request(url)
-        response = urlopen(request)
-        save_path = _path.dirname(__file__)
-        filename = _path.join(save_path, _os.path.basename(response.geturl()))
-        fh = open(filename, 'w')
-        fh.write(response.read())
-        fh.close()
-
-        #   Make sure the line endings are consistent across platforms.
-        dos2unix(filename)
+    fp = open(IAB_METADATA)
+    try:
+        for row in _csv.reader(fp):
+            (key, offset, size) = [int(_) for _ in row]
+            IAB_INDEX.setdefault(key, [])
+            IAB_INDEX[key].append((offset, size))
+    finally:
+        fp.close()
 
 #-----------------------------------------------------------------------------
 if __name__ == '__main__':
     #   Generate indices when module is executed as a script.
-    get_latest_files()
     create_indices()
 else:
     #   On module load read indices in memory to enable lookups.
     load_indices()
-
